"summary.spatial.design" <-
function (object, digits = 4, ...) 
{
    x<- object
    class(x) <- ("summary.spatial.design")
    x
}
